<?php
namespace Teknisa\PLA\Modules\Medicao\Controllers;

use \Setforms2\Shared\ORM\DateTime;
use \Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use \Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource;

class Pla01000EfetivosController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $parameterBagColumns = array();
    protected $environment;
    protected $entityManager;
    protected $efetivosService;
    protected $hasRetirada = array();
    protected $dataSourceNameToSave;
    protected $connection;
    protected $dataSourceManager;

    public function __construct($crudService, $parameterBag, $environment, $entityManager, $efetivosService, $dataSourceManager) {
        $this->crudService       = $crudService;
        $this->parameterBag      = $parameterBag;
        $this->environment       = $environment;
        $this->entityManager     = $entityManager;
        $this->efetivosService   = $efetivosService;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection        = $entityManager->getConnection();
    }

    public function getParams($request, $response) {
        try {
            $row = $request->getRow();
            $paramgeral = $this->crudService->getFilteredDataSet("paramgeral", array());
            $conditions = array(
                array(
                    "columnName" => "CDFILIAL",
                    "operator" => "=",
                    "value" => $row["CDFILIAL"]
                )
            );
            $paramplaneja = $this->crudService->getFilteredDataSet("paramplaneja", $conditions);
            $retiradas = $this->getRetiradas($row["SERVICOS"]);

            $response->addDataSet($paramgeral);
            $response->addDataSet($paramplaneja);
            $response->addDataSet($retiradas);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }
    
    public function verificaRetirada (Request\Row $request, Response $response){
        $queryRetirada = "SELECT
                   SUM(NRCARDAPIO) AS CARDAPIO
                FROM
                   RETIRADA
                WHERE
                   (CDFILIAL   = :CDFILIAL) AND
                   (NRCARDAPIO = :NRCARDAPIO)";
        $row = $request->getRow();
        $stmt = $this->connection->prepare($queryRetirada);
        $stmt->execute(array(
            "CDFILIAL"   => $row["CDFILIAL"],
            "NRCARDAPIO" => $row["NRCARDAPIO"]
        ));
        $response->addDataSet(new DataSet('RETIRADA', $stmt->fetchAll(\PDO::FETCH_ASSOC)));
    }
    
    public function getRetiradas($servicos) {
        $retiradas = array();
        foreach ($servicos as $servico) {
            $cdfilial = $servico["CDFILIAL"];
            $cdservfili = $servico["CDSERVFILI"];
            $nrcardapio = $servico["NRCARDAPIO"];
            $retirada = $this->efetivosService->getRetirada($cdfilial, $nrcardapio);
            if (empty($retirada)) {
                $retiradas[$cdservfili]  =  false;
            } else {
                $retiradas[$cdservfili]  =  true;
            }
        }
        return new DataSet("retiradas", array($retiradas));
    }

    public function saveComensais(Request\Row $request, Response $response) {
        try {
            $this->connection->beginTransaction();
            $row = $request->getRow();
            $comPla = $row["COMPLA"];
            $comFat = $row["COMFAT"];
            $this->efetivosService->saveCardadia($comPla);
            foreach ($comFat as $cliente) {
                if ($cliente["CDCLIENTE"]) {
                    $this->efetivosService->saveEfetclie($cliente, $request, $response);
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollBack();
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function saveTurno(Request\DataSet $request, Response $response) {
        try {
            $this->connection->beginTransaction();
            $turnos = $request->getDataSet()->getRows();
            foreach ($turnos as $turno) {
                $this->efetivosService->saveTurnoclie($turno);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollBack();
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }
    
    public function verificaTurnos($request, $response) {
        try {
            $row = $request->getRow();
            $dataSet = array();
            foreach($row['CDCLIENTE'] as $cliente) {
                $conditions = array(
                    array (
                        "columnName" => "CDFILIAL",
                        "operator" => "=",
                        "value" => $row["CDFILIAL"]
                    ),
                    array (
                        "columnName" => "CDSERVFILI",
                        "operator" => "=",
                        "value" => $row["CDSERVFILI"]
                    ),
                    array (
                        "columnName" => "DTDATA",
                        "operator" => "=",
                        "value" => $row["DTDATA"]
                    ),
                    array (
                        "columnName" => "CDCLIENTE",
                        "operator" => "=",
                        "value" => $cliente
                    )
                );
                $turnos = $this->crudService->getFilteredDataSet("pla01000_turno_quantidade", $conditions);
                foreach($turnos->getRows() as $turno){
                    $dataSet[] = $turno;
                }
            }
            $dataSet = new DataSet('pla01000_verificaTurnos', $dataSet);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }
}