<?php
namespace Teknisa\PLA\Modules\Prato\Controllers;

use Zeedhi\Framework\DataSource\DataSet as DataSet_Source;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class AcoesReceitaPorServico extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $pratoService;
    protected $newCode;
    protected $environment;

    protected $parameterBagColumns = array();
    protected $dataSourceManager;

    public function __construct(
        $crudService, $parameterBag, $dataSourceManager,
        \Teknisa\PLA\Modules\Prato\Services\PratoService $pratoService,
        \Teknisa\GER\Utilities\Environment $environment,
        \Teknisa\GER\Services\NewCode $newCode
    ) {
        parent::__construct($crudService, $parameterBag);
        $this->pratoService = $pratoService;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
        $this->environment = $environment;
    }

    public function replicaReceitaPorServico(
        \Zeedhi\Framework\DTO\Request\Row $request,
        \Zeedhi\Framework\DTO\Response $response
    ) {
        try {
            $row = $request->getRow();
            $tpReceita = $row['RECEITAORIGEM'];
            $filialO = $row['FILIALORIGEM'];
            if ($filialO === 'X') $filialO = null;
            $servicoO = $row['SERVICOORIGEM'];
            if ($servicoO === 'X') $servicoO = null;

            $pratos = $row['LINHASPRATO'];
            $servicos = $row['LINHASSERVICO'];
            
            $nrorg = $this->environment->getNrOrgTrab();

            $this->pratoService->iniciaTransacao();

            foreach ($servicos as $servico) {
                $percentual = $servico['PERCENTUAL'];

                if (!$percentual || $percentual <= 0) {
                    throw new \Exception('O valor do percentual deve ser maior que zero.');
                } else {
                    $percentual = str_replace(',', '.', $percentual);
                }

                $filialD = $servico['CDFILIAL'];
                $servicoD = $servico['CDSERVFILI'];

                foreach ($pratos as $prato) {
                    // EXCLUSÕES
                    // EXCLUI PRODUTOS DA RECEITA POR SERVIÇO SELECIONADO
                    $produtosReceita = $this->pratoService->retornaReceitaServico(
                        $prato['CDPRATO'], $prato['CDFILAUXPRAT'],
                        $filialD, $servicoD
                    );
                    
                    if ($produtosReceita) {
                        foreach ($produtosReceita as $produtoReceita) {
                            $this->pratoService->excluiReceita($produtoReceita);
                        }
                    }

                    // EXCLUI DADOS DA RECEITA POR SERVIÇO SELECIONADO
                    $dados = $this->pratoService->retornaPratServ(
                        $prato['CDPRATO'], $prato['CDFILAUXPRAT'],
                        $filialD, $servicoD
                    );

                    if ($dados) {
                        $this->pratoService->excluiDadosReceita($dados);
                    }

                    // EXCLUI GRAMAGEM DO PRATO DA RECEITA POR SERVIÇO SELECIONADO
                    $gramagem = $this->pratoService->retornaPratoGramagem(
                        $prato['CDPRATO'], $prato['CDFILAUXPRAT'],
                        $filialD, $servicoD
                    );
                    if ($gramagem) {
                        $this->pratoService->excluiPratoGramagem($gramagem);
                    }

                    //INSERÇÕES
                    // TIRA DA RECEITA DE ORIGEM OS PRODUTOS QUE NÃO SÃO ATIVOS NA FILIAL
                    // DE DESTINO
                    switch ($tpReceita) {
                    case 'P':
                        $receitaO = $this->pratoService->retornaReceitaPadrao($prato['CDPRATO'], $prato['CDFILAUXPRAT']);
                        $dadosReceitaO = $this->pratoService->retornaPratPadr($prato['CDPRATO'], $prato['CDFILAUXPRAT']);
                        break;
                    case 'L':
                        $receitaO = $this->pratoService->retornaReceitaLocal($prato['CDPRATO'], $prato['CDFILAUXPRAT'], $filialO);
                        $dadosReceitaO = $this->pratoService->retornaPratFili($prato['CDPRATO'], $prato['CDFILAUXPRAT'], $filialO);
                        break;
                    case 'S':
                        $receitaO = $this->pratoService->retornaReceitaServico($prato['CDPRATO'], $prato['CDFILAUXPRAT'], $filialO, $servicoO);
                        $dadosReceitaO = $this->pratoService->retornaPratServ($prato['CDPRATO'], $prato['CDFILAUXPRAT'], $filialO, $servicoO);
                        break;
                    }

                    // foreach ($receitaO as $indice => $produto) {
                    //     $prodInativo = $this->pratoService->retornaProdutoPorFilial(
                    //         $filialD, $produto->getCdproduto());

                    //     if ($prodInativo && $prodInativo->getIdprodativ() == 'I') {
                    //         unset($receitaO[$indice]);
                    //     }
                    // }

                    //Insere Receita
                    if ($receitaO) {
                        foreach ($receitaO as $prodReceitaO) {
                            $produtoInserir = array(
                                'NRORG' => $nrorg,
                                '__is_new' => true,
                                'CDFILAUXPRAT' => $prato['CDFILAUXPRAT'],
                                'CDPRATO' => $prato['CDPRATO'],
                                'CDFILIAL' => $filialD,
                                'CDSERVFILI' => $servicoD,
                                'CDPRODUTO' => $prodReceitaO->getCdproduto(),
                                'SGUNIDADE' => $prodReceitaO->getSgunidade()
                            );

                            switch ($tpReceita) {
                            case 'P':
                                $produtoInserir['QTPRODRECSER']
                                    =
                                    $prodReceitaO->getQtprodprat() * $percentual
                                    / 100;
                                $produtoInserir['VRPEFATCOCSE']
                                    = $prodReceitaO->getVrpefatcocpr();
                                $produtoInserir['VRPEFATCORSE']
                                    = $prodReceitaO->getVrpefatcorpr();
                                $produtoInserir['QTBRUTASE']
                                    =
                                    $prodReceitaO->getQtbrutapr() * $percentual
                                    / 100;
                                $produtoInserir['QTUNIDESTSE']
                                    = $prodReceitaO->getQtunidestpr()
                                    * $percentual / 100;
                                $produtoInserir['VRPEFATNUTSE']
                                    = $prodReceitaO->getVrpefatnutpr();
                                $produtoInserir['QTCALCNUTRSE']
                                    = $prodReceitaO->getQtcalcnutrpr()
                                    * $percentual / 100;
                                $produtoInserir['QTBRUTASEUNR']
                                    = $prodReceitaO->getQtbrutaprunr()
                                    * $percentual / 100;
                                $produtoInserir['HRTEMPPREPSE']
                                    = $prodReceitaO->getHrtemppreppr();

                                $produtoInserir['IDPRODBASESE']
                                    = $prodReceitaO->getIdprodbasepr();
                                $produtoInserir['IDQTDEFIXSE']
                                    = $prodReceitaO->getIdqtdefixpr();
                                $produtoInserir['IDUTCOMPENTDIRS']
                                    = $prodReceitaO->getIdutcompentdirp();
                                $produtoInserir['QTCOMPLPRODSERV']
                                    = $prodReceitaO->getQtcomplprodpadr();
                                $produtoInserir['IDTPREQPRODSERV']
                                    = $prodReceitaO->getIdtpreqprodpadr();
                                $produtoInserir['CDAPRERECE']
                                    = $prodReceitaO->getCdaprerece();
//                            $produtoInserir['QTLIMSEGSERV'] = $prodReceitaO->getQtlimsegpadr();
                                break;
                            case 'L':
                                $produtoInserir['QTPRODRECSER']
                                    = $prodReceitaO->getQtprodrecloc()
                                    * $percentual / 100;
                                $produtoInserir['VRPEFATCOCSE']
                                    = $prodReceitaO->getVrpefatcoclo();
                                $produtoInserir['VRPEFATCORSE']
                                    = $prodReceitaO->getVrpefatcorlo();
                                $produtoInserir['QTBRUTASE']
                                    =
                                    $prodReceitaO->getQtbrutalo() * $percentual
                                    / 100;
                                $produtoInserir['QTUNIDESTSE']
                                    = $prodReceitaO->getQtunidestlo()
                                    * $percentual / 100;
                                $produtoInserir['VRPEFATNUTSE']
                                    = $prodReceitaO->getVrpefatnutlo();
                                $produtoInserir['QTCALCNUTRSE']
                                    = $prodReceitaO->getQtcalcnutrlo()
                                    * $percentual / 100;
                                $produtoInserir['QTBRUTASEUNR']
                                    = $prodReceitaO->getQtbrutalounr()
                                    * $percentual / 100;
                                $produtoInserir['HRTEMPPREPSE']
                                    = $prodReceitaO->getHrtemppreplo();

                                $produtoInserir['IDPRODBASESE']
                                    = $prodReceitaO->getIdprodbaselo();
                                $produtoInserir['IDQTDEFIXSE']
                                    = $prodReceitaO->getIdqtdefixlo();
                                $produtoInserir['IDUTCOMPENTDIRS']
                                    = $prodReceitaO->getIdutcompentdirf();
                                $produtoInserir['QTCOMPLPRODSERV']
                                    = $prodReceitaO->getQtcomplprodfili();
                                $produtoInserir['IDTPREQPRODSERV']
                                    = $prodReceitaO->getIdtpreqprodfili();
                                $produtoInserir['CDAPRERECE']
                                    = $prodReceitaO->getCdaprerece();
//                            $produtoInserir['QTLIMSEGSERV'] = $prodReceitaO->getQtlimsegfili();
                                break;
                            case 'S':
                                $produtoInserir['QTPRODRECSER']
                                    = $prodReceitaO->getQtprodrecser()
                                    * $percentual / 100;
                                $produtoInserir['VRPEFATCOCSE']
                                    = $prodReceitaO->getVrpefatcocse();
                                $produtoInserir['VRPEFATCORSE']
                                    = $prodReceitaO->getVrpefatcorse();
                                $produtoInserir['QTBRUTASE']
                                    =
                                    $prodReceitaO->getQtbrutase() * $percentual
                                    / 100;
                                $produtoInserir['QTUNIDESTSE']
                                    = $prodReceitaO->getQtunidestse()
                                    * $percentual / 100;
                                $produtoInserir['VRPEFATNUTSE']
                                    = $prodReceitaO->getVrpefatnutse();
                                $produtoInserir['QTCALCNUTRSE']
                                    = $prodReceitaO->getQtcalcnutrse()
                                    * $percentual / 100;
                                $produtoInserir['QTBRUTASEUNR']
                                    = $prodReceitaO->getQtbrutaseunr()
                                    * $percentual / 100;
                                $produtoInserir['HRTEMPPREPSE']
                                    = $prodReceitaO->getHrtempprepse();

                                $produtoInserir['IDPRODBASESE']
                                    = $prodReceitaO->getIdprodbasese();
                                $produtoInserir['IDQTDEFIXSE']
                                    = $prodReceitaO->getIdqtdefixse();
                                $produtoInserir['IDUTCOMPENTDIRS']
                                    = $prodReceitaO->getIdutcompentdirs();
                                $produtoInserir['QTCOMPLPRODSERV']
                                    = $prodReceitaO->getQtcomplprodserv();
                                $produtoInserir['IDTPREQPRODSERV']
                                    = $prodReceitaO->getIdtpreqprodserv();
                                $produtoInserir['CDAPRERECE']
                                    = $prodReceitaO->getCdaprerece();
//                            $produtoInserir['QTLIMSEGSERV'] = $prodReceitaO->getQtlimsegserv();
                                break;
                            }

                            $requestInsertProduto
                                = new \Zeedhi\Framework\DTO\Request\Row(
                                $produtoInserir, '', '', ''
                            );
                            $produtoInserir = $this->crudService->getRowsToSave(
                                $requestInsertProduto, "receserv"
                            );
                            $this->crudService->save(
                                "receserv", $produtoInserir
                            );
                        }
                    }

                    // Insere dados da receita
                    if ($dadosReceitaO) {
                        $pratPadrInserir = array(
                            'NRORG'        => $nrorg,
                            '__is_new'     => true,
                            'CDFILAUXPRAT' => $prato['CDFILAUXPRAT'],
                            'CDPRATO'      => $prato['CDPRATO'],
                            'CDFILIAL'     => $filialD,
                            'CDSERVFILI'   => $servicoD,
                            'DSPRATO'      => ""
                        );

                        switch ($tpReceita) {
                        case 'P':
                            $pratPadrInserir['NRCORPRISERV']
                                = $dadosReceitaO->getNrcorpriprat();
                            $pratPadrInserir['NRCORSEQSERV']
                                = $dadosReceitaO->getNrcorseqprat();
                            $pratPadrInserir['NRCORAUXSERV']
                                = $dadosReceitaO->getNrcorauxprat();
                            $pratPadrInserir['QTPADRAOSERV']
                                =
                                $dadosReceitaO->getQtpadraoprat() * $percentual
                                / 100;
                            $pratPadrInserir['QTCONTAISERV']
                                = $dadosReceitaO->getQtcontaiprat();
                            $pratPadrInserir['HRVALCONSERV']
                                = $dadosReceitaO->getHrvalconprat();
                            $pratPadrInserir['NMFANTASIASE']
                                = $dadosReceitaO->getNmfantasiapr();
                            $pratPadrInserir['QTCARBOPRSER']
                                = $dadosReceitaO->getQtcarboprpad();
                            $pratPadrInserir['QTLIPIDPRSER']
                                = $dadosReceitaO->getQtlipidprpad();
                            $pratPadrInserir['QTPROTEPRSER']
                                = $dadosReceitaO->getQtproteprpad();
                            $pratPadrInserir['QTCALORPRSER']
                                = $dadosReceitaO->getQtcalorprpad();
                            $pratPadrInserir['QTALCOOPRSER']
                                = $dadosReceitaO->getQtalcooprpad();
                            $pratPadrInserir['VRPEMINSERV']
                                = $dadosReceitaO->getVrpeminpadr();
                            $pratPadrInserir['QTAMOSTRSERV']
                                = $dadosReceitaO->getQtamostrpadr();
                            $pratPadrInserir['CDPRODPRODUCAO']
                                = $dadosReceitaO->getCdprodproducao();
                            $pratPadrInserir['QTLIMSEGSERV']
                                = $dadosReceitaO->getQtlimsegpadr();
                            $pratPadrInserir['IDPRODCHILL']
                                = $dadosReceitaO->getIdprodchill();
                            $pratPadrInserir['IDTPPRODCHILL']
                                = $dadosReceitaO->getIdtpprodchill();
                            $pratPadrInserir['IDFINALSERV']
                                = $dadosReceitaO->getIdfinalpadr();
                            break;
                        case 'L':
                            $pratPadrInserir['NRCORPRISERV']
                                = $dadosReceitaO->getNrcorprifili();
                            $pratPadrInserir['NRCORSEQSERV']
                                = $dadosReceitaO->getNrcorseqfili();
                            $pratPadrInserir['NRCORAUXSERV']
                                = $dadosReceitaO->getNrcorauxfili();
                            $pratPadrInserir['QTPADRAOSERV']
                                =
                                $dadosReceitaO->getQtpadraofili() * $percentual
                                / 100;
                            $pratPadrInserir['QTCONTAISERV']
                                = $dadosReceitaO->getQtcontaifili();
                            $pratPadrInserir['HRVALCONSERV']
                                = $dadosReceitaO->getHrvalconfili();
                            $pratPadrInserir['NMFANTASIASE']
                                = $dadosReceitaO->getNmfantasiapf();
                            $pratPadrInserir['QTCARBOPRSER']
                                = $dadosReceitaO->getQtcarboprfil();
                            $pratPadrInserir['QTLIPIDPRSER']
                                = $dadosReceitaO->getQtlipidprfil();
                            $pratPadrInserir['QTPROTEPRSER']
                                = $dadosReceitaO->getQtproteprfil();
                            $pratPadrInserir['QTCALORPRSER']
                                = $dadosReceitaO->getQtcalorprfil();
                            $pratPadrInserir['QTALCOOPRSER']
                                = $dadosReceitaO->getQtalcooprfil();
                            $pratPadrInserir['VRPEMINSERV']
                                = $dadosReceitaO->getVrpeminfili();
                            $pratPadrInserir['QTAMOSTRSERV']
                                = $dadosReceitaO->getQtamostrfili();
                            $pratPadrInserir['CDPRODPRODUCAO']
                                = $dadosReceitaO->getCdprodproducao();
                            $pratPadrInserir['QTLIMSEGSERV']
                                = $dadosReceitaO->getQtlimsegfili();
                            $pratPadrInserir['IDPRODCHILL']
                                = $dadosReceitaO->getIdprodchill();
                            $pratPadrInserir['IDTPPRODCHILL']
                                = $dadosReceitaO->getIdtpprodchill();
                            $pratPadrInserir['IDFINALSERV']
                                = $dadosReceitaO->getIdfinalfili();
                            break;
                        case 'S':
                            $pratPadrInserir['NRCORPRISERV']
                                = $dadosReceitaO->getNrcorpriserv();
                            $pratPadrInserir['NRCORSEQSERV']
                                = $dadosReceitaO->getNrcorseqserv();
                            $pratPadrInserir['NRCORAUXSERV']
                                = $dadosReceitaO->getNrcorauxserv();
                            $pratPadrInserir['QTPADRAOSERV']
                                =
                                $dadosReceitaO->getQtpadraoserv() * $percentual
                                / 100;
                            $pratPadrInserir['QTCONTAISERV']
                                = $dadosReceitaO->getQtcontaiserv();
                            $pratPadrInserir['HRVALCONSERV']
                                = $dadosReceitaO->getHrvalconserv();
                            $pratPadrInserir['NMFANTASIASE']
                                = $dadosReceitaO->getNmfantasiase();
                            $pratPadrInserir['QTCARBOPRSER']
                                = $dadosReceitaO->getQtcarboprser();
                            $pratPadrInserir['QTLIPIDPRSER']
                                = $dadosReceitaO->getQtlipidprser();
                            $pratPadrInserir['QTPROTEPRSER']
                                = $dadosReceitaO->getQtproteprser();
                            $pratPadrInserir['QTCALORPRSER']
                                = $dadosReceitaO->getQtcalorprser();
                            $pratPadrInserir['QTALCOOPRSER']
                                = $dadosReceitaO->getQtalcooprser();
                            $pratPadrInserir['VRPEMINSERV']
                                = $dadosReceitaO->getVrpeminserv();
                            $pratPadrInserir['QTAMOSTRSERV']
                                = $dadosReceitaO->getQtamostrserv();
                            $pratPadrInserir['CDPRODPRODUCAO']
                                = $dadosReceitaO->getCdprodproducao();
                            $pratPadrInserir['QTLIMSEGSERV']
                                = $dadosReceitaO->getQtlimsegserv();
                            $pratPadrInserir['IDPRODCHILL']
                                = $dadosReceitaO->getIdprodchill();
                            $pratPadrInserir['IDTPPRODCHILL']
                                = $dadosReceitaO->getIdtpprodchill();
                            $pratPadrInserir['IDFINALSERV']
                                = $dadosReceitaO->getIdfinalserv();
                            break;
                        }

                        $requestInsertPrat
                            = new \Zeedhi\Framework\DTO\Request\Row(
                            $pratPadrInserir, '', '', ''
                        );
                        
                        $pratPadrInserir = $this->crudService->getRowsToSave(
                            $requestInsertPrat, "pratserv"
                        );
                        $this->crudService->save("pratserv", $pratPadrInserir);
                    }

                    // Insere Gramagem por Prato
                    $gramagPratoInserir = array(
                        'NRORG' => $nrorg,
                        '__is_new' => true,
                        'CDFILAUXPRAT' => $prato['CDFILAUXPRAT'],
                        'CDPRATO' => $prato['CDPRATO'],
                        'CDFILIAL' => $filialD,
                        'CDSERVFILI' => $servicoD,
                        'IDORIGEMRECE' => $tpReceita === 'L' ? 'F' : $tpReceita,
                        'CDFILIALORI' => $filialO,
                        'CDSERVFILIORI' => $servicoO,
                        'VRPERCENTUAL' => $percentual
                    );

                    $requestInsertPrat = new \Zeedhi\Framework\DTO\Request\Row(
                        $gramagPratoInserir, '', '', ''
                    );
                    $gramagPratoInserir = $this->crudService->getRowsToSave(
                        $requestInsertPrat, "pratogramag"
                    );
                    $this->crudService->save("pratogramag", $gramagPratoInserir);

                }
            }

            $response->addDataset(new DataSet_Source('RETORNO', array(true)));
            $this->pratoService->commit();
        } catch (\Exception $e) {
            $this->pratoService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function percentualReceitaPorServico(
        \Zeedhi\Framework\DTO\Request\Row $request,
        \Zeedhi\Framework\DTO\Response $response
    ) {
        try {
            $row = $request->getRow();
            
            $servicos = $row['LINHASSERVICO'];
            $filialD = $row['CDFILIALD'];
            $prato = $row['CDPRATOO'];
            $filAuxPrat = $row['CDFILAUXPRATO'];

            $nrorg = $this->environment->getNrOrgTrab();

            $this->pratoService->iniciaTransacao();

            foreach ($servicos as $servico) {
                $percentual = $servico['PERCENTUAL'];
                if(isset($servico['TPRECEITAO']) && $servico['TPRECEITAO']){
                    $tpReceita = $servico['TPRECEITAO'];
                } else {
                    $tpReceita = 'P';
                }
                
                
                if ($tpReceita === 'P') {
                    $filialO = 'X';
                    $servicoO = 'X';
                } else if ($tpReceita === 'L') {
                    $filialO = $servico['CDFILIALO'];
                    $servicoO = 'X';
                } else {
                    $filialO = $servico['CDFILIALO'];
                    $servicoO = $servico['CDSERVFILIO'];
                }

                $servicoD = $servico['CDSERVFILI'];

                // EXCLUSÕES
                // EXCLUI PRODUTOS DA RECEITA POR SERVIÇO SELECIONADO
                $produtosReceita = $this->pratoService->retornaReceitaServico(
                    $prato, $filAuxPrat, $filialD, $servicoD
                );

                if ($produtosReceita) {
                    foreach ($produtosReceita as $produtoReceita) {
                        $this->pratoService->excluiReceita($produtoReceita);
                    }
                }

                // EXCLUI DADOS DA RECEITA POR SERVIÇO SELECIONADO
                $dados = $this->pratoService->retornaPratServ(
                    $prato, $filAuxPrat, $filialD, $servicoD
                );

                if ($dados) {
                    $this->pratoService->excluiDadosReceita($dados);
                }

                // EXCLUI GRAMAGEM DO PRATO DA RECEITA POR SERVIÇO SELECIONADO
                $gramagem = $this->pratoService->retornaPratoGramagem(
                    $prato, $filAuxPrat, $filialD, $servicoD
                );

                if ($gramagem) {
                    $this->pratoService->excluiPratoGramagem($gramagem);
                }

                //INSERÇÕES
                // TIRA DA RECEITA DE ORIGEM OS PRODUTOS QUE NÃO SÃO ATIVOS NA FILIAL
                // DE DESTINO
                switch ($tpReceita) {
                case 'P':
                    $receitaO = $this->pratoService->retornaReceitaPadrao($prato, $filAuxPrat);
                    $dadosReceitaO = $this->pratoService->retornaPratPadr($prato, $filAuxPrat);
                    break;
                case 'L':
                    $receitaO = $this->pratoService->retornaReceitaLocal($prato, $filAuxPrat, $filialO);
                    $dadosReceitaO = $this->pratoService->retornaPratFili($prato, $filAuxPrat, $filialO);
                    break;
                case 'S':
                    $receitaO = $this->pratoService->retornaReceitaServico($prato, $filAuxPrat, $filialO, $servicoO);
                    $dadosReceitaO = $this->pratoService->retornaPratServ($prato, $filAuxPrat, $filialO, $servicoO);
                    break;
                }
                
                // foreach ($receitaO as $indice => $produto) {
                //     $prodInativo = $this->pratoService->retornaProdutoPorFilial(
                //         $filialD, $produto->getCdproduto());

                //     if ($prodInativo && $prodInativo->getIdprodativ() == 'I') {
                //         unset($receitaO[$indice]);
                //     }
                // }

                //Insere Receita
                if ($receitaO) {
                    foreach ($receitaO as $prodReceitaO) {
                        $produtoInserir = array(
                            'NRORG' => $nrorg,
                            '__is_new' => true,
                            'CDFILAUXPRAT' => $filAuxPrat,
                            'CDPRATO' => $prato,
                            'CDFILIAL' => $filialD,
                            'CDSERVFILI' => $servicoD,
                            'CDPRODUTO' => $prodReceitaO->getCdproduto(),
                            'SGUNIDADE' => $prodReceitaO->getSgunidade()
                        );

                        switch ($tpReceita) {
                        case 'P':
                            $produtoInserir['QTPRODRECSER']
                                =
                                $prodReceitaO->getQtprodprat() * $percentual
                                / 100;
                            $produtoInserir['VRPEFATCOCSE']
                                = $prodReceitaO->getVrpefatcocpr();
                            $produtoInserir['VRPEFATCORSE']
                                = $prodReceitaO->getVrpefatcorpr();
                            $produtoInserir['QTBRUTASE']
                                =
                                $prodReceitaO->getQtbrutapr() * $percentual
                                / 100;
                            $produtoInserir['QTUNIDESTSE']
                                = $prodReceitaO->getQtunidestpr()
                                * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']
                                = $prodReceitaO->getVrpefatnutpr();
                            $produtoInserir['QTCALCNUTRSE']
                                = $prodReceitaO->getQtcalcnutrpr()
                                * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']
                                = $prodReceitaO->getQtbrutaprunr()
                                * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']
                                = $prodReceitaO->getHrtemppreppr();

                            $produtoInserir['IDPRODBASESE']
                                = $prodReceitaO->getIdprodbasepr();
                            $produtoInserir['IDQTDEFIXSE']
                                = $prodReceitaO->getIdqtdefixpr();
                            $produtoInserir['IDUTCOMPENTDIRS']
                                = $prodReceitaO->getIdutcompentdirp();
                            $produtoInserir['QTCOMPLPRODSERV']
                                = $prodReceitaO->getQtcomplprodpadr();
                            $produtoInserir['IDTPREQPRODSERV']
                                = $prodReceitaO->getIdtpreqprodpadr();
                            $produtoInserir['CDAPRERECE']
                                = $prodReceitaO->getCdaprerece();
//                            $produtoInserir['QTLIMSEGSERV'] = $prodReceitaO->getQtlimsegpadr();
                            break;
                        case 'L':
                            $produtoInserir['QTPRODRECSER']
                                = $prodReceitaO->getQtprodrecloc()
                                * $percentual / 100;
                            $produtoInserir['VRPEFATCOCSE']
                                = $prodReceitaO->getVrpefatcoclo();
                            $produtoInserir['VRPEFATCORSE']
                                = $prodReceitaO->getVrpefatcorlo();
                            $produtoInserir['QTBRUTASE']
                                =
                                $prodReceitaO->getQtbrutalo() * $percentual
                                / 100;
                            $produtoInserir['QTUNIDESTSE']
                                = $prodReceitaO->getQtunidestlo()
                                * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']
                                = $prodReceitaO->getVrpefatnutlo();
                            $produtoInserir['QTCALCNUTRSE']
                                = $prodReceitaO->getQtcalcnutrlo()
                                * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']
                                = $prodReceitaO->getQtbrutalounr()
                                * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']
                                = $prodReceitaO->getHrtemppreplo();

                            $produtoInserir['IDPRODBASESE']
                                = $prodReceitaO->getIdprodbaselo();
                            $produtoInserir['IDQTDEFIXSE']
                                = $prodReceitaO->getIdqtdefixlo();
                            $produtoInserir['IDUTCOMPENTDIRS']
                                = $prodReceitaO->getIdutcompentdirf();
                            $produtoInserir['QTCOMPLPRODSERV']
                                = $prodReceitaO->getQtcomplprodfili();
                            $produtoInserir['IDTPREQPRODSERV']
                                = $prodReceitaO->getIdtpreqprodfili();
                            $produtoInserir['CDAPRERECE']
                                = $prodReceitaO->getCdaprerece();
//                            $produtoInserir['QTLIMSEGSERV'] = $prodReceitaO->getQtlimsegfili();
                            break;
                        case 'S':
                            $produtoInserir['QTPRODRECSER']
                                = $prodReceitaO->getQtprodrecser()
                                * $percentual / 100;
                            $produtoInserir['VRPEFATCOCSE']
                                = $prodReceitaO->getVrpefatcocse();
                            $produtoInserir['VRPEFATCORSE']
                                = $prodReceitaO->getVrpefatcorse();
                            $produtoInserir['QTBRUTASE']
                                =
                                $prodReceitaO->getQtbrutase() * $percentual
                                / 100;
                            $produtoInserir['QTUNIDESTSE']
                                = $prodReceitaO->getQtunidestse()
                                * $percentual / 100;
                            $produtoInserir['VRPEFATNUTSE']
                                = $prodReceitaO->getVrpefatnutse();
                            $produtoInserir['QTCALCNUTRSE']
                                = $prodReceitaO->getQtcalcnutrse()
                                * $percentual / 100;
                            $produtoInserir['QTBRUTASEUNR']
                                = $prodReceitaO->getQtbrutaseunr()
                                * $percentual / 100;
                            $produtoInserir['HRTEMPPREPSE']
                                = $prodReceitaO->getHrtempprepse();

                            $produtoInserir['IDPRODBASESE']
                                = $prodReceitaO->getIdprodbasese();
                            $produtoInserir['IDQTDEFIXSE']
                                = $prodReceitaO->getIdqtdefixse();
                            $produtoInserir['IDUTCOMPENTDIRS']
                                = $prodReceitaO->getIdutcompentdirs();
                            $produtoInserir['QTCOMPLPRODSERV']
                                = $prodReceitaO->getQtcomplprodserv();
                            $produtoInserir['IDTPREQPRODSERV']
                                = $prodReceitaO->getIdtpreqprodserv();
                            $produtoInserir['CDAPRERECE']
                                = $prodReceitaO->getCdaprerece();
//                            $produtoInserir['QTLIMSEGSERV'] = $prodReceitaO->getQtlimsegserv();
                            break;
                        }

                        $requestInsertProduto
                            = new \Zeedhi\Framework\DTO\Request\Row(
                            $produtoInserir, '', '', ''
                        );
                        $produtoInserir = $this->crudService->getRowsToSave(
                            $requestInsertProduto, "receserv"
                        );

                        $this->crudService->save(
                            "receserv", $produtoInserir
                        );
                    }
                }

                // Insere dados da receita
                if ($dadosReceitaO) {
                    $pratPadrInserir = array(
                        'NRORG' => $nrorg,
                        '__is_new' => true,
                        'CDFILAUXPRAT' => $filAuxPrat,
                        'CDPRATO' => $prato,
                        'CDFILIAL' => $filialD,
                        'CDSERVFILI' => $servicoD,
                        'DSPRATO' => ''
                    );

                    switch ($tpReceita) {
                    case 'P':
                        $pratPadrInserir['NRCORPRISERV']
                            = $dadosReceitaO->getNrcorpriprat();
                        $pratPadrInserir['NRCORSEQSERV']
                            = $dadosReceitaO->getNrcorseqprat();
                        $pratPadrInserir['NRCORAUXSERV']
                            = $dadosReceitaO->getNrcorauxprat();
                        $pratPadrInserir['QTPADRAOSERV']
                            =
                            $dadosReceitaO->getQtpadraoprat() * $percentual
                            / 100;
                        $pratPadrInserir['QTCONTAISERV']
                            = $dadosReceitaO->getQtcontaiprat();
                        $pratPadrInserir['HRVALCONSERV']
                            = $dadosReceitaO->getHrvalconprat();
                        $pratPadrInserir['NMFANTASIASE']
                            = $dadosReceitaO->getNmfantasiapr();
                        $pratPadrInserir['QTCARBOPRSER']
                            = $dadosReceitaO->getQtcarboprpad();
                        $pratPadrInserir['QTLIPIDPRSER']
                            = $dadosReceitaO->getQtlipidprpad();
                        $pratPadrInserir['QTPROTEPRSER']
                            = $dadosReceitaO->getQtproteprpad();
                        $pratPadrInserir['QTCALORPRSER']
                            = $dadosReceitaO->getQtcalorprpad();
                        $pratPadrInserir['QTALCOOPRSER']
                            = $dadosReceitaO->getQtalcooprpad();
                        $pratPadrInserir['VRPEMINSERV']
                            = $dadosReceitaO->getVrpeminpadr();
                        $pratPadrInserir['QTAMOSTRSERV']
                            = $dadosReceitaO->getQtamostrpadr();
                        $pratPadrInserir['CDPRODPRODUCAO']
                            = $dadosReceitaO->getCdprodproducao();
                        $pratPadrInserir['QTLIMSEGSERV']
                            = $dadosReceitaO->getQtlimsegpadr();
                        $pratPadrInserir['IDPRODCHILL']
                            = $dadosReceitaO->getIdprodchill();
                        $pratPadrInserir['IDTPPRODCHILL']
                            = $dadosReceitaO->getIdtpprodchill();
                        $pratPadrInserir['IDFINALSERV']
                            = $dadosReceitaO->getIdfinalpadr();
                        break;
                    case 'L':
                        $pratPadrInserir['NRCORPRISERV']
                            = $dadosReceitaO->getNrcorprifili();
                        $pratPadrInserir['NRCORSEQSERV']
                            = $dadosReceitaO->getNrcorseqfili();
                        $pratPadrInserir['NRCORAUXSERV']
                            = $dadosReceitaO->getNrcorauxfili();
                        $pratPadrInserir['QTPADRAOSERV']
                            =
                            $dadosReceitaO->getQtpadraofili() * $percentual
                            / 100;
                        $pratPadrInserir['QTCONTAISERV']
                            = $dadosReceitaO->getQtcontaifili();
                        $pratPadrInserir['HRVALCONSERV']
                            = $dadosReceitaO->getHrvalconfili();
                        $pratPadrInserir['NMFANTASIASE']
                            = $dadosReceitaO->getNmfantasiapf();
                        $pratPadrInserir['QTCARBOPRSER']
                            = $dadosReceitaO->getQtcarboprfil();
                        $pratPadrInserir['QTLIPIDPRSER']
                            = $dadosReceitaO->getQtlipidprfil();
                        $pratPadrInserir['QTPROTEPRSER']
                            = $dadosReceitaO->getQtproteprfil();
                        $pratPadrInserir['QTCALORPRSER']
                            = $dadosReceitaO->getQtcalorprfil();
                        $pratPadrInserir['QTALCOOPRSER']
                            = $dadosReceitaO->getQtalcooprfil();
                        $pratPadrInserir['VRPEMINSERV']
                            = $dadosReceitaO->getVrpeminfili();
                        $pratPadrInserir['QTAMOSTRSERV']
                            = $dadosReceitaO->getQtamostrfili();
                        $pratPadrInserir['CDPRODPRODUCAO']
                            = $dadosReceitaO->getCdprodproducao();
                        $pratPadrInserir['QTLIMSEGSERV']
                            = $dadosReceitaO->getQtlimsegfili();
                        $pratPadrInserir['IDPRODCHILL']
                            = $dadosReceitaO->getIdprodchill();
                        $pratPadrInserir['IDTPPRODCHILL']
                            = $dadosReceitaO->getIdtpprodchill();
                        $pratPadrInserir['IDFINALSERV']
                            = $dadosReceitaO->getIdfinalfili();
                        break;
                    case 'S':
                        $pratPadrInserir['NRCORPRISERV']
                            = $dadosReceitaO->getNrcorpriserv();
                        $pratPadrInserir['NRCORSEQSERV']
                            = $dadosReceitaO->getNrcorseqserv();
                        $pratPadrInserir['NRCORAUXSERV']
                            = $dadosReceitaO->getNrcorauxserv();
                        $pratPadrInserir['QTPADRAOSERV']
                            =
                            $dadosReceitaO->getQtpadraoserv() * $percentual
                            / 100;
                        $pratPadrInserir['QTCONTAISERV']
                            = $dadosReceitaO->getQtcontaiserv();
                        $pratPadrInserir['HRVALCONSERV']
                            = $dadosReceitaO->getHrvalconserv();
                        $pratPadrInserir['NMFANTASIASE']
                            = $dadosReceitaO->getNmfantasiase();
                        $pratPadrInserir['QTCARBOPRSER']
                            = $dadosReceitaO->getQtcarboprser();
                        $pratPadrInserir['QTLIPIDPRSER']
                            = $dadosReceitaO->getQtlipidprser();
                        $pratPadrInserir['QTPROTEPRSER']
                            = $dadosReceitaO->getQtproteprser();
                        $pratPadrInserir['QTCALORPRSER']
                            = $dadosReceitaO->getQtcalorprser();
                        $pratPadrInserir['QTALCOOPRSER']
                            = $dadosReceitaO->getQtalcooprser();
                        $pratPadrInserir['VRPEMINSERV']
                            = $dadosReceitaO->getVrpeminserv();
                        $pratPadrInserir['QTAMOSTRSERV']
                            = $dadosReceitaO->getQtamostrserv();
                        $pratPadrInserir['CDPRODPRODUCAO']
                            = $dadosReceitaO->getCdprodproducao();
                        $pratPadrInserir['QTLIMSEGSERV']
                            = $dadosReceitaO->getQtlimsegserv();
                        $pratPadrInserir['IDPRODCHILL']
                            = $dadosReceitaO->getIdprodchill();
                        $pratPadrInserir['IDTPPRODCHILL']
                            = $dadosReceitaO->getIdtpprodchill();
                        $pratPadrInserir['IDFINALSERV']
                            = $dadosReceitaO->getIdfinalserv();
                        break;
                    }

                    $requestInsertPrat
                        = new \Zeedhi\Framework\DTO\Request\Row(
                        $pratPadrInserir, '', '', ''
                    );
                    $pratPadrInserir = $this->crudService->getRowsToSave(
                        $requestInsertPrat, "pratserv"
                    );
                    $this->crudService->save("pratserv", $pratPadrInserir);
                }

                // Insere Gramagem por Prato
                $gramagPratoInserir = array(
                    'NRORG' => $nrorg,
                    '__is_new' => true,
                    'CDFILAUXPRAT' => $filAuxPrat,
                    'CDPRATO' => $prato,
                    'CDFILIAL' => $filialD,
                    'CDSERVFILI' => $servicoD,
                    'IDORIGEMRECE' => $tpReceita === 'L' ? 'F' : $tpReceita,
                    'CDFILIALORI' => $filialO,
                    'CDSERVFILIORI' => $servicoO,
                    'VRPERCENTUAL' => $percentual
                );

                $requestInsertPrat = new \Zeedhi\Framework\DTO\Request\Row(
                    $gramagPratoInserir, '', '', ''
                );
                $gramagPratoInserir = $this->crudService->getRowsToSave(
                    $requestInsertPrat, "pratogramag"
                );
                $this->crudService->save("pratogramag", $gramagPratoInserir);
            }

            $response->addDataset(new DataSet_Source('RETORNO', array(true)));
            $this->pratoService->commit();
        } catch (\Exception $e) {
            $this->pratoService->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }
}